@@ -20,7 +20,7 @@ logging.basicConfig()
 
 class RobotResultsParser(object):
 
-    def __init__(self, reporter, verbose):
+    def __init__(self, reporter, verbose=False):
         self._logger = logging.getLogger('Parser')
         if verbose:
             self._logger.setLevel(verbose)
@@ -32,7 +32,7 @@ class RobotResultsParser(object):
 
         self._parse_suite(test_run.suite)
 
-    def _parse_suite(self, suite, parent_suite_id=None):
+    def _parse_suite(self, suite):
         self._logger.info('`--> Parsing suite: %s' % suite.name)
 
         attributes = {
@@ -54,22 +54,22 @@ class RobotResultsParser(object):
 
         self.reporter.start_suite(suite.name, attributes)
 
-        self._parse_suites(suite, suite.id)
-        self._parse_tests(suite.tests, suite.id)
-        self._parse_keywords(suite.keywords, suite.id, None)
+        self._parse_suites(suite)
+        self._parse_tests(suite.tests)
+        self._parse_keywords(suite.keywords)
 
         self.reporter.end_suite(suite.name, attributes)
         if suite.id == 's1' and not suite.suites:
             attributes['id'] = suite.id
             self.reporter.end_suite(suite.name, attributes)
 
-    def _parse_suites(self, suite, parent_suite_id):
-        [self._parse_suite(subsuite, parent_suite_id) for subsuite in suite.suites]
+    def _parse_suites(self, suite):
+        [self._parse_suite(subsuite) for subsuite in suite.suites]
 
-    def _parse_tests(self, tests, suite_id):
-        [self._parse_test(test, suite_id) for test in tests]
+    def _parse_tests(self, tests):
+        [self._parse_test(test) for test in tests]
 
-    def _parse_test(self, test, suite_id):
+    def _parse_test(self, test):
         self._logger.info('  `--> Parsing test: %s' % test.name)
 
         attributes = {
@@ -88,14 +88,14 @@ class RobotResultsParser(object):
 
         self.reporter.start_test(test.name, attributes)
 
-        self._parse_keywords(test.keywords, None, test.id)
+        self._parse_keywords(test.keywords)
 
         self.reporter.end_test(test.name, attributes)
 
-    def _parse_keywords(self, keywords, suite_id, test_id, keyword_id=None):
-        [self._parse_keyword(keyword, suite_id, test_id, keyword_id) for keyword in keywords]
+    def _parse_keywords(self, keywords):
+        [self._parse_keyword(keyword) for keyword in keywords]
 
-    def _parse_keyword(self, keyword, suite_id, test_id, keyword_id):
+    def _parse_keyword(self, keyword):
 
         attributes = {
             'type': keyword.type,
@@ -113,12 +113,12 @@ class RobotResultsParser(object):
 
         self.reporter.start_keyword(keyword.name, attributes)
 
-        self._parse_messages(keyword.messages, keyword_id)
-        self._parse_keywords(keyword.keywords, None, None, keyword_id)
+        self._parse_messages(keyword.messages)
+        self._parse_keywords(keyword.keywords)
 
         self.reporter.end_keyword(keyword.name, attributes)
 
-    def _parse_messages(self, messages, keyword_id):
+    def _parse_messages(self, messages):
         for message in messages:
             self.reporter.log_message({'message': message.message, 'level': message.level,
                                        'timestamp': message.timestamp, 'html': message.html})
